@@ -1132,6 +1132,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
 @look_shop.got("type", prompt="您想要查看植物还是僵尸?")
 async def _(bot: Bot, event: MessageEvent, state: T_State):
     res = ""
+    print(state["type"])
     if state["type"] == "植物":
         res += "当前在售的植物有：\n"
         for i in range(len(all_plants)):
@@ -1558,6 +1559,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
 
 def write_data(path: Path, data: list) -> bool:
     try:
+        print(path)
         if data:
             flag = 0
             for info in data:
@@ -1572,16 +1574,19 @@ def write_data(path: Path, data: list) -> bool:
             with open(path, 'w') as f:
                 f.write('')
         return STATE_OK
-    except BaseException:
+    except BaseException as e:
+        print(e)
         return STATE_ERROR
 
 
 def read_data(path: Path) -> (bool, list):
     try:
+        print(path)
         with open(path, 'r', encoding='utf-8') as f:
             data = f.readlines()
         infos = [x.split() for x in data]
 
         return STATE_OK, infos
-    except BaseException:
+    except BaseException as e:
+        print(e)
         return STATE_ERROR, []
