@@ -3,4 +3,4 @@ from pathlib import Path
 
 
 class Config(BaseModel, extra=Extra.ignore):
-    pvz_path: Path = Path()
\ No newline at end of file
+    pvz_basic_path: Path = Path('.')
\ No newline at end of file
